@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Net::INET6Glue::INET_is_INET6;
-our $VERSION = 0.2;
+our $VERSION = 0.5;
 
 ############################################################################
 # copy IO::Socket::INET to IO::Socket::INET4
@@ -10,9 +10,23 @@ our $VERSION = 0.2;
 use IO::Socket::INET;
 use IO::Socket::INET6;
 $INC{'IO/Socket/INET4.pm'} = $INC{'IO/Socket/INET.pm'};
-$INC{'IO/Socket/INET.pm'} = $INC{'IO/Socket/INET6.pm'};
-%{IO::Socket::INET4::} = %{IO::Socket::INET::};
-%{IO::Socket::INET::} = %{IO::Socket::INET6::};
+$INC{'IO/Socket/INET.pm'}  = $INC{'IO/Socket/INET6.pm'};
+
+{
+	# copy subs
+	no strict 'refs';
+	no warnings 'redefine';
+	for ( keys %{IO::Socket::INET::} ) {
+		ref(my $v = $IO::Socket::INET::{$_}) and next;
+		*{'IO::Socket::INET4::'.$_} = \&{ "IO::Socket::INET::$_" } if *{$v}{CODE};
+	}
+
+	for ( keys %{IO::Socket::INET6::} ) {
+		ref(my $v = $IO::Socket::INET6::{$_}) and next;
+		*{'IO::Socket::INET::'.$_} = \&{ "IO::Socket::INET6::$_" } if *{$v}{CODE};
+	}
+}
+
 
 1;
 
